@@ -1,6 +1,6 @@
 import logging
 import datetime
-import os
+import os, sys
 
 
 class Logger(object):
@@ -16,6 +16,16 @@ class Logger(object):
         self.__setupFileLog(filename)
         self.__setupConsoleLog()
 
+        # python 3.6 版本 不支持`stacklevel`参数关键字，需要另设置 `.d .i .w .e .x` 方法
+        ver = sys.version_info
+        if ver.major < 3 or (ver.major == 3 and ver.minor <= 6):
+            self.d = self.logger.debug
+            self.i = self.logger.info
+            self.w = self.logger.warning
+            self.e = self.logger.error
+            self.x = self.logger.critical
+            self.exc = self.logger.exception
+
     def __setupFileLog(self, file):
         if file is None or len(file) == 0:
             return
@@ -82,14 +92,15 @@ def makeFilePath(path):
 
 def test():
     log = Logger()
-    log.d('debug', 1, 'a', {'k':'v'})
-    log.i('info', 'some info')
-    log.e('error', 123, 3*5)
+    log.d('debug')
+    log.i('info')
+    log.e('error')
     try:
         a = 1/0
         log.d(a)
     except:
         log.exc('做除法的时候出错')
+    log.i('come here')
     pass
 
 
