@@ -7,6 +7,7 @@ import re
 # 数据已存在时的操作
 ea_ignore = 'ignore'
 ea_replace = 'replace'
+ea_update = 'update'
 
 
 def fill_empty_fields(keys, data):
@@ -68,6 +69,9 @@ class DBManager(object):
             pre_sql = 'replace into %s (%s) values(%s)' % (table, fields, pre_values)
         elif exist_action == ea_ignore:
             pre_sql = 'insert ignore into %s (%s) values(%s)' % (table, fields, pre_values)
+        elif exist_action == ea_update:
+            updates = ','.join([f'{key}=values({key})' for key in keys])
+            pre_sql = 'insert into %s (%s) values(%s)  on duplicate key update %s' % (table, fields, pre_values, updates)
         else:
             pre_sql = 'insert into %s (%s) values(%s)' % (table, fields, pre_values)
         session = None
@@ -88,6 +92,13 @@ class DBManager(object):
             if session:
                 session.close()
 
+    def update(self, table, data):
+        '''
+        如果按唯一索引，有重复项，则更新data内的数据，其他不变
+        如果没有，则插入
+        '''
+        return self.insert(table, data, exist_action=ea_update)
+
     def execute(self, sql):
         session = None
         try:
