@@ -276,7 +276,7 @@ class Progress(object):
 
 
 class Retry(object):
-    def __init__(self, func, args=(), retry=3, delay=1, default=None):
+    def __init__(self, func, args=(), retry=3, delay=60, default=None, error_callback=None):
         """
         对方法进行重试
         :param func: 需要重试的方法
@@ -284,12 +284,14 @@ class Retry(object):
         :param retry: （除了初次执行的一次）额外重试的次数
         :param delay: 重试时间间隔
         :param default: 默认的返回值
+        :param error_callback: 错误处理的回调
         """
         self._func = func
         self._args = args
         self._retry = retry
         self._delay = delay
         self._default = default
+        self._error_callback = error_callback
 
     def start(self):
         result = self._default
@@ -298,7 +300,8 @@ class Retry(object):
                 result = self._func(*self._args)
                 break
             except Exception as e:
-                traceback.print_exc()  # 输出调用信息
+                if callable(self._error_callback):
+                    self._error_callback(traceback.format_exc())
                 if self._retry == 0:
                     print("[Retry]Retry failed, error: %s" % e)
                     break
@@ -306,6 +309,5 @@ class Retry(object):
             self._retry = self._retry - 1
         return result
 
-
 if __name__ == '__main__':
     pass
